"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MiniRenderer = void 0;
const marked_1 = require("marked");
class MiniRenderer {
    constructor(options = {}) {
        this.options = options;
    }
    render(content) {
        if (!content) {
            return '<p>Please select a file to view its content.</p>';
        }
        // Step 1: Protect code blocks
        const { content: processedContent, blocks } = this.preprocessContent(content);
        // Step 2: Parse markdown
        const rendered = marked_1.marked.parse(processedContent);
        // Step 3: Restore code blocks and add copy buttons
        return this.restoreContent(rendered, blocks);
    }
    preprocessContent(content) {
        let blocks = [];
        let counter = 0;
        // Helper function to store and replace content
        const store = (match, lang, code) => {
            const id = `BLOCK_${counter++}`;
            blocks.push({ id, content: code, lang });
            return id;
        };
        // Protect code blocks and preserve language specifier
        // Use negative lookbehind to avoid matching escaped backslashes
        content = content.replace(/(?<!\\)```(\w*)\n([\s\S]*?)(?<!\\)```/g, store);
        return { content, blocks };
    }
    renderMarkdownInCodeBlock(content) {
        return marked_1.marked.parse(content);
    }
    restoreContent(content, blocks) {
        blocks.forEach(({ id, content: originalContent, lang }) => {
            const languageLabel = `<span class="language-label">${lang || 'text'}</span>`;
            if (lang === 'markdown') {
                const renderedMarkdown = this.renderMarkdownInCodeBlock(originalContent);
                content = content.replace(id, `<div class="code-block-container"><div class="rendered-markdown-container"><div class="rendered-markdown">${renderedMarkdown}</div><div class="raw-markdown" style="display:none;">${originalContent}</div></div>${languageLabel}</div>`);
            }
            else {
                content = content.replace(id, `<div class="code-block-container"><pre><code class="language-${lang}">${originalContent}</code></pre>${languageLabel}</div>`);
            }
        });
        return content;
    }
}
exports.MiniRenderer = MiniRenderer;
